@@ -27,7 +27,7 @@ from fedmsg.tests.test_meta import Base
 class TestKojiBuildTag(Base):
     """ Koji emits these messages when a build has a certain tag added to it.
     """
-    expected_title = "buildsys.tag (unsigned)"
+    expected_title = "buildsys.tag"
     expected_subti = "ralph's stage-4.1.1-3.fc18 tagged into " + \
         "f18-updates-testing-pending by bodhi"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
@@ -59,7 +59,7 @@ class TestKojiBuildTag(Base):
 
 class TestKojiBuildUnTag(Base):
     """ Koji emits these messages anytime a tag is removed from a build. """
-    expected_title = "buildsys.untag (unsigned)"
+    expected_title = "buildsys.untag"
     expected_subti = "ralph's globus-gram-job-manager-sge-1.5-2.fc16 " + \
         "untagged from f16-updates-pending by bodhi"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
@@ -103,7 +103,7 @@ class TestKojiBuildStateChangeStart(Base):
 
     The example here is one of a new build **starting**.
     """
-    expected_title = "buildsys.build.state.change (unsigned)"
+    expected_title = "buildsys.build.state.change"
     expected_subti = "ralph's eclipse-ptp-6.0.3-1.fc19 started building"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
@@ -141,7 +141,7 @@ class TestKojiBuildStateChangeStartNoOwner(Base):
     was unable to publish the name of the owner of a build.  The 'owner' field
     is set to None.
     """
-    expected_title = "buildsys.build.state.change (unsigned)"
+    expected_title = "buildsys.build.state.change"
     expected_subti = "eclipse-ptp-6.0.3-1.fc19 started building"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
@@ -184,7 +184,7 @@ class TestKojiBuildStateChangeFail(Base):
 
     The example here is one of a build **failing**.
     """
-    expected_title = "buildsys.build.state.change (unsigned)"
+    expected_title = "buildsys.build.state.change"
     expected_subti = "rmattes's eclipse-ptp-6.0.3-1.fc19 failed to build"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
@@ -215,7 +215,7 @@ class TestKojiBuildStateChangeFail(Base):
 
 class TestKojiRepoInit(Base):
     """ Koji emits these messages when a repository begins initializing. """
-    expected_title = "buildsys.repo.init (unsigned)"
+    expected_title = "buildsys.repo.init"
     expected_subti = 'Repo initialized:  f19-build'
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
@@ -241,7 +241,7 @@ class TestKojiRepoInit(Base):
 
 class TestKojiRepoDone(Base):
     """ Koji emits these messages when repo initialization finishes. """
-    expected_title = "buildsys.repo.done (unsigned)"
+    expected_title = "buildsys.repo.done"
     expected_subti = 'Repo done:  f19-build'
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
@@ -267,7 +267,7 @@ class TestKojiRepoDone(Base):
 
 class TestKojiPackageListChange(Base):
     """ Koji emits these messages a package listing changes. """
-    expected_title = "buildsys.package.list.change (unsigned)"
+    expected_title = "buildsys.package.list.change"
     expected_subti = "Package list change for almanah:  'f17'"
     expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
         "Artwork_DesignService_koji-icon-48.png"
