@@ -29,7 +29,7 @@ class TestPlanetNewPost(Base):
     messages of this topic whenever a new blog post is found.  Cool!
     """
 
-    expected_title = "planet.post.new (unsigned)"
+    expected_title = "planet.post.new"
     expected_subti = 'ralph posted "Test Post 6"'
     expected_link = "http://threebean.org/blog/test-post-6"
     expected_secondary_icon = "https://secure.gravatar.com/avatar/" + \
